@@ -4,8 +4,8 @@ from collections import OrderedDict
 from functools import total_ordering
 from itertools import chain
 
+from django.core.exceptions import FieldDoesNotExist
 from django.db import models
-from django.db.models.fields import FieldDoesNotExist
 from django.utils.html import format_html_join
 
 
@@ -68,6 +68,18 @@ class OrderBy(str):
 
     QUERYSET_SEPARATOR = "__"
 
+    def __new__(cls, value):
+        instance = super().__new__(cls, value)
+        if Accessor.LEGACY_SEPARATOR in value:
+            message = (
+                f"Use '__' to separate path components, not '.' in accessor '{value}'"
+                " (fallback will be removed in django_tables2 version 3)."
+            )
+
+            warnings.warn(message, DeprecationWarning, stacklevel=3)
+
+        return instance
+
     @property
     def bare(self):
         """
@@ -118,7 +130,7 @@ class OrderBy(str):
         Returns the current instance usable in Django QuerySet's order_by
         arguments.
         """
-        return self.replace(Accessor.SEPARATOR, OrderBy.QUERYSET_SEPARATOR)
+        return self.replace(Accessor.LEGACY_SEPARATOR, OrderBy.QUERYSET_SEPARATOR)
 
 
 class OrderByTuple(tuple):
@@ -278,6 +290,9 @@ class Accessor(str):
     accesses. For convenience, the class has an alias `.A` to allow for more concise code.
 
     Relations are separated by a ``__`` character.
+
+    To support list-of-dicts from ``QuerySet.values()``, if the context is a dictionary,
+    and the accessor is a key in the dictionary, it is returned right away.
     """
 
     LEGACY_SEPARATOR = "."
@@ -294,9 +309,9 @@ class Accessor(str):
             instance.SEPARATOR = cls.LEGACY_SEPARATOR
 
             message = (
-                "Use '__' to separate path components, not '.' in accessor '{}'"
+                f"Use '__' to separate path components, not '.' in accessor '{value}'"
                 " (fallback will be removed in django_tables2 version 3)."
-            ).format(value)
+            )
 
             warnings.warn(message, DeprecationWarning, stacklevel=3)
 
@@ -304,8 +319,7 @@ class Accessor(str):
 
     def resolve(self, context, safe=True, quiet=False):
         """
-        Return an object described by the accessor by traversing the attributes
-        of *context*.
+        Return an object described by the accessor by traversing the attributes of *context*.
 
         Lookups are attempted in the following order:
 
@@ -325,6 +339,14 @@ class Accessor(str):
             >>> x.resolve("brad")
             "B"
 
+        If the context is a dictionary and the accessor-value is a key in it,
+        the value for that key is immediately returned::
+
+            >>> x = Accessor("user__first_name")
+            >>> x.resolve({"user__first_name": "brad"})
+            "brad"
+
+
         Arguments:
             context : The root/first object to traverse.
             safe (bool): Don't call anything with `alters_data = True`
@@ -337,6 +359,10 @@ class Accessor(str):
             TypeError`, `AttributeError`, `KeyError`, `ValueError`
             (unless `quiet` == `True`)
         """
+        # Short-circuit if the context contains a key with the exact name of the accessor,
+        # supporting list-of-dicts data returned from values_list("related_model__field")
+        if isinstance(context, dict) and self in context:
+            return context[self]
 
         try:
             current = context
@@ -366,10 +392,10 @@ class Accessor(str):
                             )
                 if callable(current):
                     if safe and getattr(current, "alters_data", False):
-                        raise ValueError(self.ALTERS_DATA_ERROR_FMT.format(method=repr(current)))
+                        raise ValueError(self.ALTERS_DATA_ERROR_FMT.format(method=current.__name__))
                     if not getattr(current, "do_not_call_in_templates", False):
                         current = current()
-                # important that we break in None case, or a relationship
+                # Important that we break in None case, or a relationship
                 # spanning across a null-key will raise an exception in the
                 # next iteration, instead of defaulting.
                 if current is None:
